<?php

function perk_sanitize_text_field ( $value ) {
	return sanitize_text_field($value);
}

function perk_sanitize_font ( $value ) {
	if ($value == '1' || $value == '2' || $value == '3' || $value == '4') {
		return $value;
	} else {
		return '1';
	}
}

function perk_sanitize_color_choice( $value ) {
	$choices = array(
			'PERK_MAGENTA_TAN',      
			'PERK_BLUE_GREY_YELLOW',
			'PERK_RED_GREY',        
			'PERK_BLUE_GREY',      
			'PERK_EARTH',            
			'PERK_GREY',           
			'PERK_PASTEL',         
			'PERK_PURPLE',         
			'PERK_RED',            
			'PERK_PINK',            
			'PERK_SEA',             
			'PERK_YELLOW',          
			'PERK_GREEN',          
			'custom'
	);
	
	if (in_array($value, $choices)) {
		return $value;
	} else {
		return 'PERK_MAGENTA_TAN';
	}
}

function perk_sanitize_color_hex( $value ) {
	return sanitize_hex_color( $value );
}

add_action( 'customize_register', 'perk_customize_register' );
function perk_customize_register( $wp_customize ) {
	
	// FONTS
	$wp_customize->add_section( 'perk_fonts', array (
			'title'          => __( 'Fonts', 'perk' ),
			'priority'       => 36,
	) );
	
	$wp_customize->add_setting( 'perk_theme_options[font]', array (
			'default'        => '1',
			'type'           => 'option',
			'capability'     => 'edit_theme_options',
			'sanitize_callback' => 'perk_sanitize_font',
	) );
	
	$wp_customize->add_control( 'perk_fonts', array (
			'label'      => __( 'Fonts', 'perk' ),
			'description' => '',
			'section'    => 'perk_fonts',
			'settings'   => 'perk_theme_options[font]',
			'type'       => 'radio',
			'choices'    => array(
					'1' => 'Montserrat & Martel',
					'2' => 'Oswald & Josefin Sans',
					'3' => 'Lobster & Raleway',
					'4' => 'Anton & Playfair'
			),
	) );

	// COLORS
	$wp_customize->add_section( 'perk_color_scheme', array(
			'title'          => __( 'Color Scheme', 'perk' ),
			'priority'       => 35,
	) );

	$wp_customize->add_setting( 'perk_theme_options[color_scheme]', array(
			'default'        => 'perk_MAGENTA_TAN',
			'type'           => 'option',
			'capability'     => 'edit_theme_options',
			'sanitize_callback' => 'perk_sanitize_color_choice',
	) );

	$wp_customize->add_control( 'perk_color_scheme', array(
			'label'      => __( 'Color Scheme', 'perk' ),
			'description' => '',
			'section'    => 'perk_color_scheme',
			'settings'   => 'perk_theme_options[color_scheme]',
			'type'       => 'radio',
			'choices'    => array(
    			    'PERK_MAGENTA_TAN'      => __('Magenta & Tan', 'perk'),
    			    'PERK_BLUE_GREY_YELLOW' => __('Blue, Grey & Yellow', 'perk'),
    			    'PERK_RED_GREY'         => __('Red & Grey', 'perk'),
    			    'PERK_BLUE_GREY'        => __('Blue & Grey', 'perk'),
    			    'PERK_EARTH'            => __('Earth', 'perk'),
    			    'PERK_GREY'             => __('Grey', 'perk'),
    			    'PERK_PASTEL'           => __('Pastel', 'perk'),
    			    'PERK_PURPLE'           => __('Purple', 'perk'),
    			    'PERK_RED'              => __('Red', 'perk'),
    			    'PERK_PINK'             => __('Pink', 'perk'),
    			    'PERK_SEA'              => __('Sea', 'perk'),
    			    'PERK_YELLOW'           => __('Yellow', 'perk'),
    			    'PERK_GREEN'            => __('Green', 'perk'),
    				'custom'                => __('Custom (Use The Colors Below)', 'perk')
			),
	) );	
	
	
	// main color
	$txtcolors[] = array(
			'slug'=>'color_1',
			'default' => '#002a32',
	       'label' => __('Main Color', 'perk')
	);
	
	// secondary color
	$txtcolors[] = array(
			'slug'=>'color_2',
			'default' => '#f40076',
	       'label' => __('Secondary Color', 'perk')
	);
	
	// 3rd
	$txtcolors[] = array(
			'slug'=>'color_3',
			'default' => '#bc5f04',
	       'label' => __('Tertiary Color', 'perk')
	);
	
	// 4th
	$txtcolors[] = array(
			'slug'=>'color_4',
			'default' => '#fb8b24',
	       'label' => __('Accent Color 1', 'perk')
	);
	
	// 5th
	$txtcolors[] = array(
			'slug'=>'color_5',
			'default' => '#d90368',
	       'label' => __('Accent Color 2', 'perk')
	);
	
	// 6th
	$txtcolors[] = array(
			'slug'=>'color_black',
			'default' => '#000000',
	       'label' => __('Black Color', 'perk')
	);
	
	// 7th 
	$txtcolors[] = array(
			'slug'=>'color_white',
			'default' => '#ffffff',
	       'label' => __('White Color', 'perk')
	);
	
	// add the settings and controls for each color
	foreach( $txtcolors as $txtcolor ) {
		$wp_customize->add_setting( "perk_theme_colors[" . $txtcolor['slug'] . "]", array(
						'default' => $txtcolor['default'],
						'type' => 'option',
						'sanitize_callback' => 'perk_sanitize_color_hex',
						'capability' => 'edit_theme_options'
				)
		);

		$wp_customize->add_control(
				new WP_Customize_Color_Control(
						$wp_customize, $txtcolor['slug'],
						array(
								'label' => $txtcolor['label'],
								'section' => 'perk_color_scheme',
								'settings' => "perk_theme_colors[" . $txtcolor['slug'] . "]")
						)
		);
	}

	//  WP_Customize_Color_Control is a class that is extending the built in WP_Customize_Control class. It adds the color wheel jazz to places where color selection is needed
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'link_color', array(
			'label'   => __( 'Link Color', 'perk' ),
			'section' => 'perk_color_scheme',
			'settings'   => 'perk_theme_options[link_color]',
	) ) );
	
	// HOMEPAGE HEADER
	$wp_customize->add_setting( 'perk_hero_text', array ( 'sanitize_callback' => 'perk_sanitize_text_field', ) );
	
	$wp_customize->add_control( 'header_text', array(
			'label'    => __( 'Header Text', 'perk' ),
			'section'  => 'header_image',
			'settings' => 'perk_hero_text',
			'type'    => 'text',
	) );
}



function perk_customize_colors() {

	$colors = get_option( 'perk_theme_colors' );
	$options = get_option( 'perk_theme_options' );

	$black = '#000000'; //$colors['color_black'];
	$white = '#ffffff'; //$colors['color_white'];
	
	$scheme = ( isset($options['color_scheme'] ) ? $options['color_scheme'] : '');
	$font   = ( isset($options['font'] ) ? $options['font'] : '');
}
add_action( 'wp_head', 'perk_customize_colors' );

?>